/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Klasse, um aus einem Objekt mit tatsächlichen Attributwerten einen entsprechenden DOM-Knoten zu machen
*/
function RectNodeBuilder() {
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten
* @return SVGElement    Erstellter DOM-Knoten
*/
RectNodeBuilder.prototype.create = function(
    atts        // Objekt mit den tatsächlichen Attributwerten
) {
    var r = Math.min(atts.breite, atts.hoehe) / 2 * atts.abrundung;
    return ScoTools.createSvg('rect', undefined, {
        x: (atts.links + 1) * 10,
        y: (atts.oben + 1) * 10,
        width: atts.breite * 10,
        height: atts.hoehe * 10,
        rx: r * 10,
        ry: r * 10,
        fill: atts.fuellung,
        stroke: atts.umrandung,
        'stroke-width': atts.strichdicke * 10
    });
}

/**
* Erstellt einen DOM-Knoten anhand von Attributwerten und ersetzt nodeOld durch den neu erstellten Knoten bzw. fügt ihn am Ende von parentNode ein
* @return SVGElement    Erstellter DOM-Knoten
*/
RectNodeBuilder.prototype.change = function(
    atts,       // Objekt mit den tatsächlichen Attributwerten
    nodeOld,    // Zu ersetzender DOM-Knoten
    parentNode  // Übergeordneter DOM-Knoten
) {
    var node = this.create(atts);
    if (nodeOld && nodeOld.parentNode)
        nodeOld.parentNode.replaceChild(node, nodeOld);
    else
        parentNode.appendChild(node);
    return node;
}
